==> payroll_ver_3.2.0.zip: payroll3/src/jp/mosp/common/vo/MosPMenuGuideVo.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common.vo;

import jp.mosp.common.CommonConst;
import jp.mosp.common.MosPVo;
import jp.mosp.common.common.MospException;

public class MosPMenuGuideVo extends MosPVo {

	private static final long serialVersionUID = -7765659615461284319L;

	// URL
	private static final String RETURN_URL = "/jsp/common/menuGuide.jsp";
	private static final String EXTRA_JS   = "/pub/common/js/menuGuide.js";
	private static final String EXTRA_CSS  = "/pub/common/css/menuGuide.css";

	// ʃTu^Cg	
	public final String TTL_MOSP_MENU_GUIDE = CommonConst.TTL_MOSP_MENU_GUIDE;


	// 萔
	public static final int MODE_IMPOSSIBLE 		= 0;
	public static final int MODE_POSSIBLE 		= 1;

	// tB[h
	public String[][] aryMenuGuide ;

	/**
	 * RXgN^
	 */
	public MosPMenuGuideVo() {
		super();
		setRetUrl(RETURN_URL);
		setExtraCss(EXTRA_CSS);
		addExtraJs(EXTRA_JS);
		aryMenuGuide = new String[0][0];
	}

	/**
	 * tB[hݒ
	 * @param String[][] 
	 * @throws MospException
	 */
	public void setFields(String [][] aryMenuGuide) throws MospException {
		this.aryMenuGuide = escapeArray(aryMenuGuide.clone());
	}

	/**
	 * JavaScriptݒ
	 * @param cls 擾NX
	 * @throws IllegalAccessException
	 */
	@Override
	public String getDirectJs(Class cls) throws IllegalAccessException {
		StringBuffer sb = new StringBuffer();
		sb.append(super.getDirectJs(cls));
		return sb.toString();
	}

	public String[][]	getEscAryMenuGuide	() { return aryMenuGuide.clone()	; }

}

==> payroll_ver_3.3.1.zip: payroll3/src/jp/mosp/common/vo/MosPMenuGuideVo.java <==
/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.common.vo;

import jp.mosp.common.CommonConst;
import jp.mosp.common.MosPVo;

/**
 * @author yoshida
 *
 */
public class MosPMenuGuideVo extends MosPVo {
	
	private static final long	serialVersionUID	= -7765659615461284319L;
	
	// tB[h
	/**
	 * 
	 */
	public String[][]			aryMenuGuide;
	
	// tB[hyѐ
	/**
	 * j[KCh
	 */
	public String				NAM_MOSP_MENU_GUIDE;
	

	/**
	 * RXgN^
	 */
	public MosPMenuGuideVo() {
		super();
		setViewPath(getClassName());
		aryMenuGuide = new String[0][0];
	}
	
	@Override
	protected void setFieldsName() {
		NAM_MOSP_MENU_GUIDE = CommonConst.TTL_MOSP_MENU_GUIDE;
	}
	
	// ANZT\bh	
	/**
	 * @return aryMenuGuide
	 */
	public String[][] getAryMenuGuide() {
		return aryMenuGuide.clone();
	}
	
	/**
	 * @param aryMenuGuide Zbg aryMenuGuide
	 */
	public void setAryMenuGuide(String[][] aryMenuGuide) {
		this.aryMenuGuide = aryMenuGuide.clone();
	}
	
}
